# NeoDjango

[![Build Status](https://travis-ci.org/RenanPalmeira/neodjango.svg?branch=master)](https://travis-ci.org/RenanPalmeira/neodjango)

### Demo/Example

https://github.com/RenanPalmeira/neodjango-starwars-example

Installation

Available in Python Package Index:

$ pip install neodjango

Or:

$ easy_install neodjango
